@@ -131,18 +131,23 @@ class LokiEmitterV1:
         def process():
             while not self.thread_stop.is_set():
                 records = []
-                for _ in range(self.handler.max_records_in_one_request):
-                    try:
-                        records.append(
-                            self.queue.get(block=True,
-                                           timeout=self.handler.send_interval))
-                    except Empty:
-                        break
-                if records:
-                    try:
-                        self.emit(records)
-                    except LokiServerError:
-                        self.handler.handleError(records[0])
+                try:
+                    for _ in range(self.handler.max_records_in_one_request):
+                        try:
+                            records.append(
+                                self.queue.get(
+                                    block=True,
+                                    timeout=self.handler.send_interval))
+                        except Empty:
+                            break
+                    if records:
+                        try:
+                            self.emit(records)
+                        except LokiServerError:
+                            self.handler.handleError(records[0])
+                except Exception as ex:
+                    if sys.stderr:
+                        sys.stderr.write(f"[CRITICAL LOKI ERROR]\n{ex}\n")
 
         self.thread = Thread(target=process, name="loggate", daemon=True)
         self.thread.start()
@@ -150,21 +155,25 @@ class LokiEmitterV1:
     def asyncio_start(self):
         async def process(is_full_asyncio):
             while not self.thread_stop.is_set():
-                records = []
-                for _ in range(self.handler.max_records_in_one_request):
-                    try:
-                        records.append(self.queue.get(block=False))
-                    except Empty:
-                        break
-                if records:
-                    try:
-                        if is_full_asyncio:
-                            await self.emit_async(records)
-                        else:
-                            self.emit(records)
-                    except LokiServerError:
-                        self.handler.handleError(records[0])
-                else:
-                    await asyncio.sleep(self.handler.send_interval)
+                try:
+                    records = []
+                    for _ in range(self.handler.max_records_in_one_request):
+                        try:
+                            records.append(self.queue.get(block=False))
+                        except Empty:
+                            break
+                    if records:
+                        try:
+                            if is_full_asyncio:
+                                await self.emit_async(records)
+                            else:
+                                self.emit(records)
+                        except LokiServerError:
+                            self.handler.handleError(records[0])
+                    else:
+                        await asyncio.sleep(self.handler.send_interval)
+                except Exception as ex:
+                    if sys.stderr:
+                        sys.stderr.write(f"[CRITICAL LOKI ERROR]\n{ex}\n")
         is_full_asyncio = asyncio.iscoroutinefunction(self.api.send_json)
         asyncio.get_event_loop().create_task(process(is_full_asyncio))
